@@ -18,12 +18,18 @@
 # under the License.
 
 from aliyunsdkcore.request import RpcRequest
+from aliyunsdkvcs.endpoint import endpoint_data
 
 class GetDeviceLiveUrlRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Vcs', '2020-05-15', 'GetDeviceLiveUrl')
+		RpcRequest.__init__(self, 'Vcs', '2020-05-15', 'GetDeviceLiveUrl','vcs')
 		self.set_method('POST')
+		if hasattr(self, "endpoint_map"):
+			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
+		if hasattr(self, "endpoint_regional"):
+			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
+
 
 	def get_CorpId(self):
 		return self.get_body_params().get('CorpId')
@@ -35,10 +41,4 @@ class GetDeviceLiveUrlRequest(RpcRequest):
 		return self.get_body_params().get('GbId')
 
 	def set_GbId(self,GbId):
-		self.add_body_params('GbId', GbId)
-
-	def get_DeviceId(self):
-		return self.get_body_params().get('DeviceId')
-
-	def set_DeviceId(self,DeviceId):
-		self.add_body_params('DeviceId', DeviceId)
\ No newline at end of file
+		self.add_body_params('GbId', GbId)
\ No newline at end of file
